@@ -19,6 +19,9 @@ class DockerService:
             if di.labels.get('app', '') == 'pier' and di.attrs.get('RepoTags')
         ]
 
+    def search(self, term):
+        return self.client.images.search(term)
+
     def pull_image(self, tag):
         fileobj = io.BytesIO(bytes(f'FROM {tag}', 'utf-8'))
         self.client.images.build(fileobj=fileobj, rm=True, tag=tag, labels=self.APP_LABEl)
